{ bracein
} braceout
GENOME genome 
GENE gene
FITNESS fitness
FITNESSOP fitnessop
OUTGOING outg
INCOMING inc
OUTGOINGNTH outnth
INCOMINGNTH incnth
INTEGRAL integral
GRADIENT gradient
DIGIT digit
ALPHNUM alphanum
VAR [A-Za-z]+ ### any alpha
